@@ -201,13 +201,6 @@ class Service(web.Application):
             port = kwargs.get('bind_port')
 
         self.logging.info(f"Starting {self.NAME.capitalize()} service on [{host}:{port}]")
-
-        self.logging.info("Available routes:")
-        for row in handlers:
-            if 'ping' in row[0] or row[0] == r"/.*":
-                continue
-            self.logging.info(f" * {row[0]}")
-
         self.listen(address=host, port=port)
         for queue in queues:
             self.io_loop.add_callback(queue)
